@@ -398,7 +398,7 @@ class Schema:
             name = name.replace("australium", "").strip()
             item["australium"] = True
         
-        if "festivized" in name:
+        if "festivized" in name and "festivized formation" not in name:
             name = name.replace("festivized", "").strip()
             item["festive"] = True
 
@@ -411,7 +411,8 @@ class Schema:
             'haunted hat',
             'unusual cap',
             'vintage tyrolean',
-            'vintage merryweather'
+            'vintage merryweather',
+            'haunted kraken'
         ]
 
         qualitySearch = name
@@ -465,6 +466,9 @@ class Schema:
             if effect == "accursed" and "accursed apparition" in name:
                 # Accursed Apparition never be an unusual
                 continue
+            if effect == "haunted" and "haunted kraken" in name:
+                # Skip Haunted effect if name include Haunted Kraken
+                continue
             if effect == "hot": 
                 # shotgun # shot to hell
                 # plaid potshotter # shot in the dark
